@@ -1,4 +1,4 @@
-from .cli import cli
+from .cli import cli, defaults
 
 if __name__ == "__main__":
     cli(auto_envvar_prefix="AXIOS")
